@@ -4,12 +4,15 @@ class EntityTime(object):
     Before = -1
     After = 1
 
+
 class Entity(object):
+    """Base class of all entities that are contained in a neuroshare file
+    """
     def __init__(self, entity_id, nsfile, entity_info):
         self._info = entity_info
         self._id = entity_id
         self._file = nsfile
-        
+
     @property
     def id(self):
         """The entity id of this entity"""
@@ -40,16 +43,28 @@ class Entity(object):
         return self._info['ItemCount']
 
     def get_time_by_index(self, index):
-        return self._file.library._get_time_by_index (self, index)
+        """Convert from a given index to the corresponding timestamp"""
+        return self._file.library._get_time_by_index(self, index)
 
     def get_index_by_time(self, timepoint, position=EntityTime.Closest):
-        return self._file.library._get_index_by_time (self, timepoint, position)
-    
+        """Convert from a given timestamp to the corresponding index.
+        The position argument controls how the timestamp is matched to the index.
+        Options are:
+
+        * before and inclusive of the timepoint (``EntityTime.Before``)
+        * after and inclusive of the timepoint (``EntityTime.After``)
+        * closest to timepoint (``EntityTime.Closest``) [default]
+        """
+        return self._file.library._get_index_by_time(self, timepoint, position)
+
+    def __len__(self):
+        return self.item_count
+
+
 class EntityType(object):
+    Unknown = 0
     Unkown = 0
     Event = 1
     Analog = 2
     Segment = 3
     Neural = 4
-    
-
